package BallandBeamControllerDeploy "Model of ball and beam"
  model BallandBeamControllerDeployModel "Displacement of the ball based on gravity"
    parameter Modelica.Units.SI.Acceleration g = 9.81 "Gravitational Pull";
    parameter Modelica.Units.SI.Mass m = 0.01 "Mass of ball";
    Modelica.Mechanics.Translational.Interfaces.Flange_b flange_b1 annotation(Placement(visible = true, transformation(origin = {120, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput u "Angle of the beam" annotation(Placement(visible = true, transformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-100, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant const(k = g * 3 / 5 * m) annotation(Placement(visible = true, transformation(origin = {-20, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Math.Sin sin annotation(Placement(visible = true, transformation(origin = {-20, -20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Math.Product product annotation(Placement(visible = true, transformation(origin = {20, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.Translational.Components.Mass ball(m = m) annotation(Placement(visible = true, transformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.Translational.Sources.Force force annotation(Placement(visible = true, transformation(origin = {60, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.Translational.Sensors.PositionSensor positionSensor1 annotation(Placement(visible = true, transformation(origin = {100, 21.578}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput s annotation(Placement(visible = true, transformation(origin = {125, 21.735}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {92.5, 35.963}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(u, sin.u) annotation(Line(visible = true, origin = {-68, -10}, points = {{-52, 10}, {8, 10}, {8, -10}, {36, -10}}, color = {0, 36, 164}));
    connect(ball.flange_b, flange_b1) annotation(Line(visible = true, origin = {113.333, 0}, points = {{-3.333, 0}, {-3.333, 0}, {6.667, 0}}, color = {0, 127, 0}));
    connect(const.y, product.u1) annotation(Line(visible = true, origin = {-0.25, 13}, points = {{-8.75, 7}, {0.25, 7}, {0.25, -7}, {8.25, -7}}, color = {1, 37, 163}));
    connect(sin.y, product.u2) annotation(Line(visible = true, origin = {-2.294, -13}, points = {{-6.706, -7}, {-1.794, -7}, {-1.794, 7}, {10.294, 7}}, color = {1, 37, 163}));
    connect(product.y, force.f) annotation(Line(visible = true, origin = {39.5, 0}, points = {{-8.5, 0}, {8.5, 0}}, color = {1, 37, 163}));
    connect(force.flange, ball.flange_a) annotation(Line(visible = true, origin = {80, 0}, points = {{-10, 0}, {10, 0}}, color = {0, 127, 0}));
    connect(positionSensor1.flange, ball.flange_a) annotation(Line(visible = true, origin = {87.5, 10.789}, points = {{2.5, 10.789}, {-2.5, 10.789}, {-2.5, -10.789}, {2.5, -10.789}}, color = {0, 127, 0}));
    connect(positionSensor1.s, s) annotation(Line(visible = true, origin = {120.333, 21.63}, points = {{-9.333, -0.053}, {4.667, -0.053}, {4.667, 0.105}}, color = {1, 37, 163}));
    annotation(Documentation(info = "<html>

    <p>
Model for the longitudinal force that is exerted on the ball, based on the angle of the beam.
</p></html>"), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Line(visible = true, origin = {0, 1.091}, rotation = -37.81, points = {{-67.184, -19.146}, {67.184, 19.146}}, thickness = 2), Polygon(visible = true, origin = {1.234, -23.808}, fillColor = {191, 194, 191}, fillPattern = FillPattern.Solid, points = {{-17.532, -11.924}, {-1.234, 23.848}, {18.766, -11.924}}), Polygon(visible = true, origin = {7.914, 35.596}, rotation = -24.207, lineColor = {0, 127, 0}, fillColor = {215, 215, 215}, fillPattern = FillPattern.Solid, points = {{-100, 10}, {20, 10}, {20, 41}, {90, 0}, {20, -41}, {20, -10}, {-100, -10}, {-100, 10}}), Line(visible = true, origin = {-50, 0}, points = {{-50, 0}, {50, 0}}, color = {0, 0, 127})}), Diagram(coordinateSystem(extent = {{-120, -60}, {120, 60}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
  end BallandBeamControllerDeployModel;
  annotation(preferredView = "info", Documentation(info = "<html>

    <p>
Model for the longitudinal force that is exerted on the ball, based
on the angle of the beam.
</p></html>"), uses(Modelica(version = "4.0.0")), __Wolfram(openClass = BallandBeamControllerDeploy.BallandBeamControllerDeployModel), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {111, 0, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-90.0, -90.0}, {90.0, 90.0}}, radius = 25), Text(visible = true, origin = {12.0, 20.8333}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-102.0, -70.8333}, {78.0, 29.1667}}, textString = "Ex", fontName = "Arial")}));
end BallandBeamControllerDeploy;
